
const utils = require('./build');
const path = require('path');
const browserSync = require('browser-sync');
const clean = require('gulp-clean');

const watcher = (src, destination, validExtensions, isProject, isReload) => {
  gulp.watch(src, (event) => {
    console.log(`> ${event.type}: ${event.path}.`);

    let file = event.path.replace('src', destination);

    if (event.type === 'deleted'){
      gulp.src(file).pipe(clean());
    } else {
      let dest = path.dirname(file);
      let eventPath = event.path;
      let extName = path.extname(event.path);
      let isIndexHtml = (path.basename(event.path) !== 'index.html');
      let isCommonStyle = (path.basename(event.path) === 'common.scss');

      if (validExtensions.includes(extName) && isIndexHtml){
        eventPath = eventPath.replace(extName, '.ts');
        if (isCommonStyle){
          eventPath = eventPath.replace('common', 'app.component');
        }
        if (isProject) {
          utils.buildProject(eventPath, dest);
        } else {
          utils.buildLibrary(eventPath, dest);
        }
      } else {
        gulp.src(eventPath).pipe(gulp.dest(dest));
      }       
    }

    if (isReload){
      browserSync.reload();
    }
  });  
};

exports.watcher = watcher;